<?php

/*
 * Picture Time Photo Album
 * An Image gallery provided by Marcel Pol under the GPL
 * Source and updates: http://timelord.nl
 */

class Album {
	protected $realpath,$name,$link,$tn_name,$tn_realpath,$nr_images,$nr_albums;

	public function __construct($album) {
		global $realpath;

		$this->realpath = $realpath . "/" . $album;

		$this->name = str_replace("_"," ",$album);

		$this->link = $album;

		$this->tn_name = $album . '/thumb.jpg';

		$this->tn_realpath = $realpath . '/' . $album . '/thumb.jpg';

		if (file_exists($this->tn_realpath)) {
			// resize the thumb.jpg
			list($width, $height) = getimagesize($this->tn_realpath);

			if (is_writable($this->tn_realpath)) {
				if ($width > 133 || $height > 100) {
					// calculate thumbnail aspect ratio
					$aspect = $width / $height;
					if ($aspect > 1.33 ) {
						$width_new = 133;
						$height_new = $height / $width * 133;
					} else if ($aspect == 1.33) {
						$width_new = 133;
						$height_new = 100;
					} else if ($aspect < 1.33) {
						$width_new = 100 * $aspect;
						$height_new = 100;
					}
					$thumb = imagecreatetruecolor($width_new, $height_new);

					// Resize
					$source = imagecreatefromjpeg($this->tn_realpath);
					imagecopyresampled($thumb, $source, 0, 0, 0, 0, $width_new, $height_new, $width, $height);

					// Output
					imagejpeg($thumb,$this->tn_realpath);

					// Free up memory
					imagedestroy($source);
					imagedestroy($thumb);
				}
			}
		}

		// add counters for albums and images
		$scandir = scandir($this->realpath);
		$albums_counter = 0;
		$images_counter = 0;
		foreach ($scandir as $scanfile) {
			if (is_file($this->realpath . "/" . $scanfile)) {
				if (exif_imagetype($this->realpath . "/" . $scanfile)) {
					if ($scanfile != "thumb.jpg") {
						$images_counter++;
					}
				}
			} else if (is_dir($this->realpath . "/" . $scanfile)) {
				if ($scanfile != "tn" && $scanfile != ".." && $scanfile != ".") {
						$albums_counter++;
				}
			}
		}
		$this->nr_images = $images_counter;
		$this->nr_albums = $albums_counter;
	}

	// the getter methods
	public function get_realpath() {
		return $this->realpath;
	}
	public function get_name() {
		return $this->name;
	}
	public function get_link() {
		return $this->link;
	}
	public function get_tn_name() {
		return $this->tn_name;
	}
	public function get_tn_realpath() {
		return $this->tn_realpath;
	}
	public function get_nr_images() {
		return $this->nr_images;
	}
	public function get_nr_albums() {
		return $this->nr_albums;
	}
}

?>