<?php

/*
 * Picture Time Photo Album
 * An Image gallery provided by Marcel Pol under the GPL
 * Source and updates: http://timelord.nl
 */

class Image {
	protected $name,$realpath,$date,$type,$tn_name,$tn_realpath,$tn_date;

	public function __construct($image) {
		global $realpath;

		$this->name = $image;

		$this->realpath = $realpath . "/" . $image;

		if (file_exists($realpath . "/" . $image)) {
			$this->date = date ("YmdHis", filemtime($realpath . "/" . $image));
		} else {
			$this->date = "";
		}

		$this->type = exif_imagetype($this->realpath);

		$this->tn_name = 'tn/' . $image;

		$this->tn_realpath = $realpath . "/tn/" . $image;

		if (file_exists($this->tn_realpath)) {
			$this->tn_date = date ("YmdHis", filemtime($this->tn_realpath));
		} else {
			$this->tn_date = "";
		}
	}
	public function gen_tn($image) {
		if ($this->type == 2) {
			$source = imagecreatefromjpeg($this->realpath);
		} else if ($this->type == 3) {
			$source = imagecreatefrompng($this->realpath);
		} else if ($this->type == 1) {
			$source = imagecreatefromgif($this->realpath);
		}

		// Get old sizes
		list($width, $height) = getimagesize($this->realpath);

		// calculate thumbnail aspect ratio
		$aspect = $width / $height;
		if ($aspect > 1.33 ) {
			$width_new = 133;
			$height_new = $height / $width * 133;
		} else if ($aspect == 1.33) {
			$width_new = 133;
			$height_new = 100;
		} else if ($aspect < 1.33) {
			$width_new = 100 * $aspect;
			$height_new = 100;
		}
		$thumb = imagecreatetruecolor($width_new, $height_new);

		// Resize
		imagecopyresampled($thumb, $source, 0, 0, 0, 0, $width_new, $height_new, $width, $height);

		// Output
		if ($this->type == 2) {
			imagejpeg($thumb,$this->tn_realpath);
		} else if ($this->type == 3) {
			imagepng($thumb,$this->tn_realpath);
		} else if ($this->type == 1) {
			imagegif($thumb,$this->tn_realpath);
		}

		// Free up memory
		imagedestroy($source);
		imagedestroy($thumb);
	}

	// the getter methods
	public function get_realpath() {
		return $this->realpath;
	}
	public function get_name() {
		return $this->name;
	}
	public function get_date() {
		return $this->date;
	}
	public function get_type() {
		return $this->type;
	}
	public function get_tn_name() {
		return $this->tn_name;
	}
	public function get_tn_realpath() {
		return $this->tn_realpath;
	}
	public function get_tn_date() {
		return $this->tn_date;
	}
}

?>
